# Chores

This app is mainly a tool for me to learn python.

From end-user perspective, you can see this app as an recuring todo list.

I use it to manage my housekeeping chores.

So i can define what sould be done, how, and what is the period, (nb days).

I then get an ordererd list of chores to be done.